@@ -32,7 +32,7 @@ class insert_if_not_exists:
             storage = session.exec(
                 sqm.select(schema_core.storage).where(schema_core.storage.root == root)
             ).first()
-        if not storage:
+        if storage is None:
             root = insert.storage(root, region)  # type: ignore
 
         return root
@@ -76,10 +76,12 @@ class insert:
         settings = load_or_create_instance_settings()
         engine = settings.db_engine()
 
-        if "s3" in root:
+        if str(root).startswith("s3://"):
             storage_type = "s3"
+        elif str(root).startswith("gs://"):
+            storage_type = "gs"
         else:
-            storage_type = None
+            storage_type = "local"
 
         with sqm.Session(engine) as session:
             storage = schema_core.storage(root=root, region=region, type=storage_type)
