@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Optional, Union
+from typing import Union
 
 import lnschema_core
 import sqlmodel as sqm
@@ -33,6 +33,12 @@ def configure_schema_wetlab(schema_modules):
             f.write(content)
 
 
+def update_db(isettings, usettings):
+    insert_if_not_exists.user(usettings.email, usettings.id, usettings.handle)
+
+    insert_if_not_exists.storage(isettings.storage_dir, isettings.storage_region)
+
+
 def setup_instance_db():
     """Setup database.
 
@@ -104,29 +110,24 @@ def setup_instance_db():
             f" v{lnschema_core.__version__}: {isettings._sqlite_file}"
         )
 
-    insert_if_not_exists.user(
-        user_settings.email, user_settings.id, user_settings.handle
-    )
-
-    insert_if_not_exists.storage(isettings.storage_dir, isettings.storage_region)
+    update_db(isettings, user_settings)
 
 
 def load(instance_name: str):
     """Load existing instance."""
-    InstanceSettings.name
-    instance_settings = load_instance_settings(
-        settings_dir / f"instance-{instance_name}.env"
-    )
-    assert instance_settings.name is not None
-    save_instance_settings(instance_settings)
+    user_settings = load_or_create_user_settings()
+    isettings = load_instance_settings(settings_dir / f"instance-{instance_name}.env")
+    assert isettings.name is not None
+    save_instance_settings(isettings)
 
     from ._settings import settings
 
     settings._instance_settings = None
 
+    update_db(isettings, user_settings)
+
 
 @doc_args(
-    description.storage_dir,
     description.storage_dir,
     description._dbconfig,
     description.schema_modules,
@@ -134,7 +135,6 @@ def load(instance_name: str):
 def init(
     *,
     storage: Union[str, Path, CloudPath],
-    storage_region: Optional[str] = None,
     dbconfig: str = "sqlite",
     schema: Union[str, None] = None,
 ) -> Union[None, str]:
@@ -142,7 +142,6 @@ def init(
 
     Args:
         storage: {}
-        storage_region: {}
         dbconfig: {}
         schema: {}
     """
@@ -156,6 +155,18 @@ def init(
 
     # setup storage
     instance_settings.storage_dir = setup_storage_dir(storage)
+    storage_root_str = str(instance_settings.storage_dir)
+    storage_region = None
+    if storage_root_str.startswith("s3://"):
+        import boto3
+
+        response = boto3.client("s3").get_bucket_location(
+            Bucket=storage_root_str.replace("s3://", "")
+        )
+        # returns `None` for us-east-1
+        # returns a string like "eu-central-1" etc. for all other regions
+        storage_region = response["LocationConstraint"]
+
     instance_settings.storage_region = storage_region
 
     # setup _config
